import asyncio
import json
import sys
from typing import Union, Dict, List

import aiohttp


def super_print(data, offset: int = 0):
    """

    Debug stuff, prints data beautifully

    :param data: data to print
    :param offset: offset left (int)
    :return: nothing, just prints

    """
    if isinstance(data, list):
        for item in data:
            try:
                super_print(item, offset + 1)
            except:
                print('--' * (offset + 1) + f' {data}')
    elif isinstance(data, dict):
        for k, v in data.items():
            print('--' * (offset + 1) + f' {k}')
            try:
                super_print(v, offset + 2)
            except:
                print('--' * (offset + 2) + f' {v}')
    else:
        print('--' * (offset + 1) + ' ' + data)


class InstaChecker:

    def __init__(
            self,
            cookie: Union[str, None] = None,
            proxy: Union[str, None] = None,
            user_agent: Union[str, None] = None,
            timeout: float = 1,
            max_async_requests_count: int = 10,
            debug: bool = False
    ):

        """

        Initialize InstaChecker

        :param cookie: Instagram cookie, you must take it after auth, to get requests' statuses ok (str)
        :param proxy: Proxy, if needed (str) ex: http://user:pass@some.proxy.com
        :param user_agent: User-Agent header property (str)
        :param timeout: Sleep after request in seconds (float)
        :param max_async_requests_count: Maximum count of async requests (int)
        :param debug: Show debug messages or not (bool)

        """

        self.ready = True
        self.debug = debug
        self.proxy = proxy
        self.timeout = timeout
        self.max_async_requests_count = max_async_requests_count

        self.user_agent = user_agent
        if self.user_agent is None:
            self.user_agent = ''

        self.cookie = cookie
        if self.cookie is None:
            self.cookie = ''
            print('InstaChecker - No cookie provided')
            self.ready = False

        if self.max_async_requests_count > 10:
            print(f"InstaChecker - WARNING, you're trying to fetch {self.max_async_requests_count} asynchronously, it more then 10 urls and can be dangerous for your cookies")

        if self.timeout < 1:
            print(
                f"InstaChecker - WARNING, your timeout ({self.timeout}) is less then 1 secound, it can be dangerous for your cookies")

        self.headers = {
            'cookie': self.cookie,
            'user-agent': self.user_agent,
            'User-Agent': self.user_agent
        }

    async def check_conf(self):

        """

        Checking provided cookie + user-agent + proxy configuration

        :return: Nothing, just changes ready param of instance

        """

        session = aiohttp.ClientSession()
        url = 'https://www.instagram.com/antonnechaev990/'
        response = await self.get_response(url, session)
        self.ready = response[url]['success']
        await session.close()
        if self.ready:
            print(f"InstaChecker - Config OK")
        else:
            print(f"InstaChecker - Config FAIL, errors: {','.join(response[url]['errors'])}")

    async def run(
            self,
            urls: Union[List[str], None] = None,
            check: bool = True
    ) -> Union[list, str]:

        """

        Runs tasks

        :param urls: Urls to get data from (list of strings)
        :param check: To check provided cookie + user-agent + proxy configuration or not (bool)
        :return: Dictionary of results or error (dict or str)

        """

        if urls is None:
            urls = []

        if check:
            await self.check_conf()

        if self.ready:
            responses = await self.get_responses(urls)
            return responses
        else:
            print('InstaChecker - not ready, config FAILed')
            return 'Not ready'

    def deserialize_user(
            self,
            user: dict
    ) -> dict:

        """

        Translates raw user page dict to pretty info dict

        :param user: Raw dict from user page
        :return: Prettified info

        """
        result = {
            'full': user,
            'errors': []
        }
        try:
            result = {
                'full': user,
                'id': user['id'],
                'username': user['username'],
                'is_private': user['is_private'],
                'connected_fb_page': user['connected_fb_page'],
                'media_count': user['edge_owner_to_timeline_media']['count'],
                'biography': user['biography'],
                'followers': user['edge_followed_by']['count'],
                'follows': user['edge_follow']['count'],
                'full_name': user['full_name'],
                'avatar_url': user['profile_pic_url'],
                'avatar_url_hd': user['profile_pic_url_hd'],
            }
            recent_media = []
            for media_node in user['edge_owner_to_timeline_media']['edges']:
                media = media_node['node']
                recent_media.append(self.deserialize_media(media, full=False))
                recent_media.append({
                    'full': media,
                    'type': media['__typename'].replace('Graph', '').lower(),
                    'id': media['id'],
                    'shortcode': media['shortcode'],
                    'post_url': f"https://www.instagram.com/p/{media['shortcode']}/",
                    'src': media['display_url'],
                    'dimesions': media['dimensions'],
                    'thumbnail_src': media['thumbnail_src'],
                    'thumbnails': media['thumbnail_resources'],
                    'owner': media['owner'],
                    'is_video': media['is_video'],
                    'text': media['accessibility_caption'],
                    'comments': media['edge_media_to_comment']['count'],
                    'comments_disabled': media['comments_disabled'],
                    'likes': media['edge_liked_by']['count'],
                    'location': media['location'],
                    'timestamp': media['taken_at_timestamp'],
                })
            result['recent_media'] = recent_media
        except BaseException as ex:
            result['errors'].append(f'User deserialization error at line {sys.exc_info()[-1].tb_lineno}. Maybe instagram changed  API, have returned only full')
        if not len(result['errors']):
            del result['errors']
        return result

    def deserialize_media(
            self,
            media: dict,
            full: bool = True
    ) -> dict:

        """

        Translates raw media page dict to pretty info dict

        :param media: Raw dict from media page
        :param full: Was the dict got directly from the page or not (bool)
        :return: Prettified info

        """
        result = {
            'full': media,
            'errors': []
        }
        try:
            media_type = media['__typename'].replace('Graph', '').lower()
            if media_type in ['image', 'sidecar']:
                if full:
                    if media_type == 'image':
                        result = {
                            'full': media,
                            'type': media_type,
                            'id': media['id'],
                            'shortcode': media['shortcode'],
                            'post_url': f"https://www.instagram.com/p/{media['shortcode']}/",
                            'dimesions': media['dimensions'],
                            'src': media['display_url'],
                            'srcs': media['display_resources'],
                            'is_video': media['is_video'],
                            'text': media['accessibility_caption'],
                            'comments_disabled': media['comments_disabled'],
                            'likes': media['edge_media_preview_like']['count'],
                            'owner': {
                                'id': media['owner']['id'],
                                'profile_pic_url': media['owner']['profile_pic_url'],
                                'username': media['owner']['username'],
                                'media_count': media['owner']['edge_owner_to_timeline_media']['count'],
                                'full': media['owner']
                            },
                            'location': media['location'],
                            'timestamp': media['taken_at_timestamp']
                        }
                    elif media_type == 'sidecar':
                        pass
                else:
                    if media_type == 'image':
                        result = {
                            'full': media,
                            'type': media_type,
                            'id': media['id'],
                            'shortcode': media['shortcode'],
                            'post_url': f"https://www.instagram.com/p/{media['shortcode']}/",
                            'src': media['display_url'],
                            'dimesions': media['dimensions'],
                            'thumbnail_src': media['thumbnail_src'],
                            'thumbnails': media['thumbnail_resources'],
                            'is_video': media['is_video'],
                            'text': media['accessibility_caption'],
                            'comments': media['edge_media_to_comment']['count'],
                            'comments_disabled': media['comments_disabled'],
                            'likes': media['edge_liked_by']['count'],
                            'owner': media['owner'],
                            'location': media['location'],
                            'timestamp': media['taken_at_timestamp']
                        }
                    elif media_type == 'sidecar':
                        pass
            else:
                result['errors'].append(f'Media of type "{media_type}" not currently supported, returned only full')
        except BaseException as ex:
            result['errors'].append(f'Media deserialization error at line {sys.exc_info()[-1].tb_lineno}. Maybe instagram changed  API, returned only full')
        if not len(result['errors']):
            del result['errors']
        return result

    def source_to_profile(
            self,
            response_result: dict
    ) -> Dict[str, Union[bool, str, List[str]]]:

        """

        Translate instagram profile HTML source to result data

        :param response_result: HTML source str
        :return: Parsed json dict

        """

        try:
            response_result['type'] = 'profile'
            shared_data_str = response_result['data']
            shared_data_str = shared_data_str.split('window._sharedData = ')[-1]
            shared_data_str = shared_data_str.split(';')[0]
            shared_data = json.loads(shared_data_str)
            response_result['data'] = shared_data
            if 'entry_data' in response_result['data'].keys():
                response_result['data'] = response_result['data']['entry_data']
                if 'ProfilePage' in response_result['data'].keys():
                    if len(response_result['data']['ProfilePage']):
                        response_result['data'] = response_result['data']['ProfilePage'][0]
                        if 'graphql' in response_result['data'].keys():
                            response_result['data'] = response_result['data']['graphql']
                            if 'user' in response_result['data'].keys():
                                if self.debug:
                                    super_print(response_result['data'])
                                response_result['data'] = response_result['data']['user']
                                print(response_result['data'].keys())
                                deserialized_data = self.deserialize_user(response_result['data'])
                                if 'errors' in deserialized_data.keys():
                                    response_result['errors'] += deserialized_data['errors']
                                    del deserialized_data['errors']
                                response_result['data'] = deserialized_data
                            else:
                                response_result['success'] = False
                                response_result['errors'].append(
                                    f'No user in response body --> window.sharedData --> entry_data --> ProfilePage --> 0 --> graphql')
                        else:
                            response_result['success'] = False
                            response_result['errors'].append(
                                f'No graphql in response body --> window.sharedData --> entry_data --> ProfilePage --> 0')
                    else:
                        response_result['success'] = False
                        response_result['errors'].append(
                            f'ProfilePage is blank in response body --> window.sharedData --> entry_data')
                else:
                    response_result['success'] = False
                    response_result['errors'].append(
                        f'No ProfilePage in response body --> window.sharedData --> entry_data')
            else:
                response_result['success'] = False
                response_result['errors'].append(f'No entry_data in response body --> window.sharedData')
        except BaseException as ex:
            response_result['success'] = False
            response_result['errors'] = [f"Can't fetch and parse the source of page. Error: '{ex}'. On line {sys.exc_info()[-1].tb_lineno}"]

        return response_result

    def source_to_media(
            self,
            response_result: dict
    ) -> Dict[str, Union[bool, str, List[str]]]:

        """

        Translate instagram media HTML source to result data

        :param response_result: HTML source str
        :return: Parsed json dict

        """

        try:
            response_result['type'] = 'post'
            additional_data_str = response_result['data']
            additional_data_str = additional_data_str.split("window.__additionalDataLoaded('")[-1]
            additional_data_str = additional_data_str.split("/',")[1]
            additional_data_str = additional_data_str.split(');')[0]
            additional_data = json.loads(additional_data_str)
            response_result['data'] = additional_data
            if 'graphql' in response_result['data'].keys():
                response_result['data'] = additional_data['graphql']
                if 'shortcode_media' in response_result['data'].keys():
                    response_result['data'] = response_result['data']['shortcode_media']
                    if self.debug:
                        super_print(response_result['data'])
                    deserialized_data = self.deserialize_user(response_result['data'], full=True)
                    if 'errors' in deserialized_data.keys():
                        response_result['errors'] += deserialized_data['errors']
                        del deserialized_data['errors']
                    response_result['data'] = deserialized_data
                else:
                    response_result['success'] = False
                    response_result['errors'].append(
                        f"No shortcode_media in response body --> window.__additionalDataLoaded --> graphql")
            else:
                response_result['success'] = False
                response_result['errors'].append(f"No graphql in response body --> window.__additionalDataLoaded")
        except BaseException as ex:
            response_result['success'] = False
            response_result[
                'errors'] = f"Can't fetch and parse the source of page. Error: '{ex}'. On line {sys.exc_info()[-1].tb_lineno}"
        return response_result

    def source_to_data(
            self,
            response_result: Dict[str, Dict[str, Union[bool, str, List[str]]]]
    ) -> Dict[str, Dict[str, Union[bool, str, List[str]]]]:

        """

        Translate HTML source to to result data

        :param response_result: HTML source str
        :return: Parsed json dict

        """

        if "window.__additionalDataLoaded('" in response_result['data']:
            response_result = self.source_to_media(response_result)
        elif 'window._sharedData = {' in response_result['data']:
            response_result = self.source_to_profile(response_result)
        else:
            response_result['success'] = False
            response_result['errors'].append(f'No any window.(data) in response body')
        return response_result

    async def get_response(
            self,
            url: str,
            session: Union[aiohttp.ClientSession, None] = None
    ) -> Dict[str, Dict[str, Union[bool, str, List[str]]]]:

        """

        Fetches and parses the url

        :param url: Url to fetch
        :param session: aiohttp.ClientSession instance
        :return: Dict of fetch and parse result, ex: {'https://some-url.com': {'success': False, 'data': 'raw_html_data', 'errors': ['some_error']}}

        """
        if session is None:
            session = aiohttp.ClientSession()
        response_result = {
            'success': False,
            'data': '',
            'errors': [],
        }
        try:
            if self.proxy and self.headers:
                response = await session.get(url, proxy=self.proxy, headers=self.headers)
            elif self.proxy:
                response = await session.get(url, proxy=self.proxy)
            elif self.headers:
                response = await session.get(url, headers=self.headers)
            else:
                response = await session.get(url)
            if response.status == 200:
                response_result['success'] = True
                response_result['data'] = await response.text()
                response_result = self.source_to_data(response_result)
            else:
                response_result['success'] = False
                response_result['errors'].append(f'Response status is {int(response.status)}')
            if 'not-logged-in' in response_result['data']:
                response_result['success'] = False
                response_result['errors'].append('Not logged in, provide better headers')
        except BaseException as ex:
            response_result['success'] = False
            response_result['errors'].append(f"Can't fetch and parse the page. Error: '{ex}'. On line {sys.exc_info()[-1].tb_lineno}")
        await session.close()
        return {url: response_result}

    async def get_responses(
            self,
            urls: List[str]
    ) -> Dict[str, Dict[str, Union[bool, str, List[str]]]]:

        """

        Asynchronously fetches and pareses the urls

        :param urls: List of urls to fetch (list of strings)
        :return: Dict of results (dict)

        """

        responses_dict = {}
        urls = list(set(urls))
        urls_bunches_count = len(urls) // self.max_async_requests_count + int(
            len(urls) % self.max_async_requests_count != 0)
        for bunch_i in range(urls_bunches_count):
            session = aiohttp.ClientSession()
            urls_slice_from = bunch_i * self.max_async_requests_count
            urls_slice_to = (bunch_i + 1) * self.max_async_requests_count
            if len(urls) < urls_slice_to:
                urls_slice_to = len(urls)
            async_tasks = {self.get_response(url, session) for url in urls[urls_slice_from:urls_slice_to]}
            responses = await asyncio.gather(*async_tasks)
            for response in responses:
                for k, v in response.items():
                    responses_dict[k] = v
            await asyncio.sleep(self.timeout)
        if self.debug:
            super_print(responses_dict)
        return responses_dict



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

modules = \
['insta_checker']
install_requires = \
['aiohttp>=3.7.4,<4.0.0']

setup_kwargs = {
    'name': 'insta-checker',
    'version': '0.4.3',
    'description': 'Python Instagram API checker / scrapper / wrapper 2021. Fast and asynchronously scrapes instagram profiles and posts, powered by aiohttp.',
    'long_description': '# insta_checker\n\n## **Python Instagram API checker / scrapper / wrapper 2021. Fast and asynchronously scrapes instagram profiles and posts, powered by aiohttp.**\n\nMy needs for one project included scraping likes, the number of subscribers and so on from Instagram. When I wrote this library, I\'ve cheked out a huge bunch (about 30) of other scrapping libraries in Python or JavaScript. There was only one abandoned library, but it died after a month of use. Actually, I wrote my own library, which is this repository.\n\n### Working with this library, you are expected:\n\n- Fully works in 2021\n- The fastest library for requests - aiohttp\n- Fully asynchronous\n- Bunch of try except, which, if anything goes wrong, will return the available data\n- Adequate informational messages and error messages\n- Timeouts\n- Typing\n\n\n# Installation\n`pip install insta-checker`\n\n[Here is PyPi](https://pypi.org/project/insta-checker/)\n\n\n# Usage\n### Create instance of InstaChecker with keywords:\n- cookie: Instagram cookie, you must take it after auth, to get requests\' statuses ok (str)\n- proxy: Proxy, if needed (str) ex: http://user:pass@some.proxy.com\n- user_agent: User-Agent header property (str)\n- timeout: Sleep after request in seconds (float)\n- max_async_requests_count: Maximum count of async requests (int)\n- Show debug messages or not (bool)\n\nExample:\n\n```python\nchecker = InstaChecker(\n    cookie=\'cookie_string\',\n    proxy=\'http://user:pass@some.proxy.com\',\n    user_agent=\'user_agent_string\',\n    timeout=1,\n    max_async_requests_count=10,\n    debug=False\n)\n```\n\n### To use in default mode run function "run" in InstaChecker instance with params:\n - urls: List of urls\n - check: Bool, to check conf or not\n\nExample:\n\n```python\nurls_list = [\n    \'https://www.instagram.com/antonnechaev990/\'\n]\nresponses_task = await checker.run(urls_list) # async func\nfor url in urls_list:\n    print(responses[url])\n```\n\n### To scrape one url run function "get_response" in InstaChecker instance with params:\n - url: Url to scrape\n - session: aiohttp.ClientSession() or None to create a new one\n\nExample:\n\n```python\nurl = \'https://www.instagram.com/antonnechaev990/\'\ndata = await checker.get_response(url) # async func\nurl_data = data[url]\n```\n\n### To scrape data from source run function "source_to_data" in InstaChecker instance with params:\n - response_result: Dict like in the example\n\nExample:\n\n```python\nsource = \'Instagram HTML source string\'\nresponse_result = {\n    \'success\': True,\n    \'data\': source,\n    \'errors\': []\n}\ndata = checker.source_to_data(response_result) # sync func\ndata = data[\'data\']\n```\n\n# Examples\n### run.py\n```python\nfrom insta_checker import InstaChecker, super_print\nimport asyncio\n\n\nasync def main():\n    cookie = \'ds_user_id=48743733271;mid=YQgRZwAAAAEPjPkWIONy9q0lPPdu;sessionid=48743733271%3AJRUhxoYZxBh4BX%3A6;ig_nrcb=1;ig_did=A446BA65-9920-462A-BAA8-F85FEAC0AB98;csrftoken=iD5MZwMnXZHgNzm8H5kACrNHKVBIvpDz;rur="CLN\\05448743733271\\0541659454776:01f7e7cbc38f962c9fbe9fe015e28ac99145941e231df3769a1682f8ce14b2a8ca254ddf";\'\n    checker = InstaChecker(\n        cookie=cookie,\n        timeout=1,\n    )\n\n    some_wrong_url = \'https://www.instagram.com/antonnechaev990123123213213132/\'\n    profile1_url = \'https://www.instagram.com/antonnechaev990/\'\n    post1_url = \'https://www.instagram.com/p/CQlptixpNQq/\'\n    urls_to_scrape = [\n        some_wrong_url,\n        profile1_url,\n        post1_url\n    ]\n    data = await checker.run(urls_to_scrape)\n\n    """\n        returns\n        {\n            \'your-url\': {\n                \'success\': (bool),\n                \'data\': (dict),\n                \'errors\': (dict of strings)\n            }\n        }\n    """\n\n    wrong_success = data[some_wrong_url][\'success\']\n    print(f"{wrong_success = }")  # f string with = is easy format\n    if not wrong_success:\n        print(f"{data[some_wrong_url][\'errors\'] = }")\n\n    profile1_success = data[profile1_url][\'success\']\n    print(f"{profile1_success = }")\n    if profile1_success:\n        print(data[profile1_url])\n        profile1_data = data[profile1_url][\'data\']\n        print(f"{data[profile1_url][\'type\'] = }")\n        print(f"{profile1_data[\'id\'] = }")\n        print(f"{profile1_data[\'avatar_url\'] = }")\n        print(f"{profile1_data[\'followers\'] = }")\n        print(f"{profile1_data[\'follows\'] = }")\n        print(f"{profile1_data[\'media_count\'] = }")\n        print(f"{profile1_data[\'recent_media\'][0][\'text\'] = }")\n        print(\'\')\n        print(\'Printing all profile1 data:\')\n        super_print(profile1_data)\n\n    post1_success = data[post1_url][\'success\']\n    print(f"{post1_success = }")\n    if post1_success:\n        post1_data = data[post1_url][\'data\']\n        print(f"{data[post1_url][\'type\'] = }")\n        print(f"{post1_data[\'id\'] = }")\n        print(f"{post1_data[\'likes\'] = }")\n        super_print(post1_data[\'owner\'])\n        print(\'\')\n        print(\'Printing all post1 data:\')\n        super_print(post1_data)\n\n\nasyncio.run(main())\n\n```\n\nOutput:\n```python\nInstaChecker - Config OK\nwrong_success = False\ndata[some_wrong_url][\'errors\'] = ["Can\'t fetch and parse the page. Error: \'Server disconnected\'. On line 415"]\nprofile1_success = False\npost1_success = True\ndata[post1_url][\'type\'] = \'post\'\npost1_data[\'id\'] = \'2604671409127216170\'\npost1_data[\'likes\'] = 1\n-- id\n------ 48335815772\n-- profile_pic_url\n------ https://scontent-arn2-1.cdninstagram.com/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=scontent-arn2-1.cdninstagram.com&_nc_ohc=DTLSrWbkEzYAX9J25Bg&edm=AJ9x6zY\nBAAAA&ccb=7-4&oh=cdfbd95c2e902e0ba36878de94826257&oe=6115D58F&_nc_sid=cff2a4&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n-- username\n------ antonnechaev990\n-- media_count\n---- 1\n-- full\n------ id\n---------- 48335815772\n------ is_verified\n-------- False\n------ profile_pic_url\n---------- https://scontent-arn2-1.cdninstagram.com/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=scontent-arn2-1.cdninstagram.com&_nc_ohc=DTLSrWbkEzYAX9J25Bg&edm=AJ9\nx6zYBAAAA&ccb=7-4&oh=cdfbd95c2e902e0ba36878de94826257&oe=6115D58F&_nc_sid=cff2a4&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n------ username\n---------- antonnechaev990\n------ blocked_by_viewer\n-------- False\n------ restricted_by_viewer\n-------- False\n------ followed_by_viewer\n-------- False\n------ full_name\n---------- Testing\n------ has_blocked_viewer\n-------- False\n------ is_private\n-------- False\n------ is_unpublished\n-------- False\n------ requested_by_viewer\n-------- False\n------ pass_tiering_recommendation\n-------- False\n------ edge_owner_to_timeline_media\n---------- count\n------------ 1\n------ edge_followed_by\n---------- count\n------------ 1\n\nPrinting all post1 data:\n-- type\n------ image\n-- id\n------ 2604671409127216170\n-- shortcode\n------ CQlptixpNQq\n-- post_url\n------ https://www.instagram.com/p/CQlptixpNQq/\n-- dimesions\n------ height\n-------- 1080\n------ width\n-------- 1080\n-- src\n------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHYAX_FMA\nHM&edm=AABBvjUBAAAA&ccb=7-4&oh=1ba6faeba4925e7a24d76b50922a12ea&oe=61169DA8&_nc_sid=83d603\n-- srcs\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=AABBvjUBAAAA&ccb=7-4&oh=14eb7e11de612dbac35cb161dcf1e2b4&oe=61165B6A&_nc_sid=83d603\n-------- config_width\n---------- 640\n-------- config_height\n---------- 640\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s750x750/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=AABBvjUBAAAA&ccb=7-4&oh=0b5bd0a083fda0bfb7761b432ba7d07c&oe=611666F1&_nc_sid=83d603\n-------- config_width\n---------- 750\n-------- config_height\n---------- 750\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHY\nAX_FMAHM&edm=AABBvjUBAAAA&ccb=7-4&oh=1ba6faeba4925e7a24d76b50922a12ea&oe=61169DA8&_nc_sid=83d603\n-------- config_width\n---------- 1080\n-------- config_height\n---------- 1080\n-- is_video\n---- False\n-- text\n------ Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n-- comments_disabled\n---- False\n-- likes\n---- 1\n-- owner\n------ id\n---------- 48335815772\n------ profile_pic_url\n---------- https://scontent-arn2-1.cdninstagram.com/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=scontent-arn2-1.cdninstagram.com&_nc_ohc=DTLSrWbkEzYAX9J25Bg&edm=AJ9\nx6zYBAAAA&ccb=7-4&oh=cdfbd95c2e902e0ba36878de94826257&oe=6115D58F&_nc_sid=cff2a4&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n------ username\n---------- antonnechaev990\n------ media_count\n-------- 1\n------ full\n---------- id\n-------------- 48335815772\n---------- is_verified\n------------ False\n---------- profile_pic_url\n-------------- https://scontent-arn2-1.cdninstagram.com/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=scontent-arn2-1.cdninstagram.com&_nc_ohc=DTLSrWbkEzYAX9J25Bg&edm\n=AJ9x6zYBAAAA&ccb=7-4&oh=cdfbd95c2e902e0ba36878de94826257&oe=6115D58F&_nc_sid=cff2a4&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n---------- username\n-------------- antonnechaev990\n---------- blocked_by_viewer\n------------ False\n---------- restricted_by_viewer\n------------ False\n---------- followed_by_viewer\n------------ False\n---------- full_name\n-------------- Testing\n---------- has_blocked_viewer\n------------ False\n---------- is_private\n------------ False\n---------- is_unpublished\n------------ False\n---------- requested_by_viewer\n------------ False\n---------- pass_tiering_recommendation\n------------ False\n---------- edge_owner_to_timeline_media\n-------------- count\n---------------- 1\n---------- edge_followed_by\n-------------- count\n---------------- 1\n-- location\n---- None\n-- timestamp\n---- 1624721049\n```\n\n### get_response.py\n```python\nfrom insta_checker import InstaChecker, super_print\nimport asyncio\n\n\nasync def main():\n    cookie = \'ds_user_id=48743733271;mid=YQgRZwAAAAEPjPkWIONy9q0lPPdu;sessionid=48743733271%3AJRUhxoYZxBh4BX%3A6;ig_nrcb=1;ig_did=A446BA65-9920-462A-BAA8-F85FEAC0AB98;csrftoken=iD5MZwMnXZHgNzm8H5kACrNHKVBIvpDz;rur="CLN\\05448743733271\\0541659454776:01f7e7cbc38f962c9fbe9fe015e28ac99145941e231df3769a1682f8ce14b2a8ca254ddf";\'\n    checker = InstaChecker(\n        cookie=cookie\n    )\n\n    url = \'https://www.instagram.com/antonnechaev990/\'\n\n    print(f"{checker.ready = }")\n    await checker.check_conf()\n    print(f"{checker.ready = }")\n    if checker.ready:\n        print(\'Conf is ok, making stuff\')\n        # stuff\n\n    data = await checker.get_response(url)\n\n    """\n        returns\n        \'your-url\': {\n            \'success\': (bool),\n            \'data\': (dict),\n            \'errors\': (dict of strings)\n        }\n    """\n\n    data = data[url]\n    success = data[\'success\']\n    errors = data[\'errors\']\n    data = data[\'data\']\n    print(f"{success = }")\n    if success:\n        print(f"{data[\'id\'] = }")\n        print(f"{data[\'avatar_url\'] = }")\n        print(f"{data[\'followers\'] = }")\n        print(f"{data[\'follows\'] = }")\n        print(f"{data[\'media_count\'] = }")\n        print(f"{data[\'recent_media\'][0][\'text\'] = }")\n        print(\'\')\n        print(\'Printing all data:\')\n        super_print(data)\n\n\nasyncio.run(main())\n\n```\n\nOutput:\n```python\nchecker.ready = False\nInstaChecker - Config OK\nchecker.ready = True\nConf is ok, making stuff\nsuccess = True\ndata[\'id\'] = \'48335815772\'\ndata[\'avatar_url\'] = \'https://instagram.fevn6-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.fevn6-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8JfxI\nd&edm=AL4D0a4BAAAA&ccb=7-4&oh=f1d76137ab3469dab27c1b2eb5bf10f3&oe=6115D58F&_nc_sid=712cc3&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\'\ndata[\'followers\'] = 1\ndata[\'follows\'] = 2\ndata[\'media_count\'] = 1\ndata[\'recent_media\'][0][\'text\'] = "Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'."\n\nPrinting all data:\n-- id\n------ 48335815772\n-- username\n------ antonnechaev990\n-- connected_fb_page\n---- None\n-- media_count\n---- 1\n-- biography\n------\n-- followers\n---- 1\n-- follows\n---- 2\n-- full_name\n------ Testing\n-- avatar_url\n------ https://instagram.fevn6-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.fevn6-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8JfxId&edm=AL4D0a4BA\nAAA&ccb=7-4&oh=f1d76137ab3469dab27c1b2eb5bf10f3&oe=6115D58F&_nc_sid=712cc3&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n-- avatar_url_hd\n------ https://instagram.fevn6-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.fevn6-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8JfxId&edm=AL4D0a4BA\nAAA&ccb=7-4&oh=f1d76137ab3469dab27c1b2eb5bf10f3&oe=6115D58F&_nc_sid=712cc3&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n-- recent_media\n-------- type\n------------ image\n-------- id\n------------ 2604671409127216170\n-------- shortcode\n------------ CQlptixpNQq\n-------- post_url\n------------ https://www.instagram.com/p/CQlptixpNQq/\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHY\nAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n-------- dimesions\n------------ height\n-------------- 1080\n------------ width\n-------------- 1080\n-------- thumbnail_src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------- thumbnails\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n-------------- config_width\n---------------- 150\n-------------- config_height\n---------------- 150\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n-------------- config_width\n---------------- 240\n-------------- config_height\n---------------- 240\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n-------------- config_width\n---------------- 320\n-------------- config_height\n---------------- 320\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n-------------- config_width\n---------------- 480\n-------------- config_height\n---------------- 480\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=1\n09&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------------- config_width\n---------------- 640\n-------------- config_height\n---------------- 640\n-------- is_video\n---------- False\n-------- text\n------------ Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n-------- comments\n---------- 0\n-------- comments_disabled\n---------- False\n-------- likes\n---------- 1\n-------- owner\n------------ id\n---------------- 48335815772\n------------ username\n---------------- antonnechaev990\n-------- location\n---------- None\n-------- timestamp\n---------- 1624721049\n-------- type\n------------ image\n-------- id\n------------ 2604671409127216170\n-------- shortcode\n------------ CQlptixpNQq\n-------- post_url\n------------ https://www.instagram.com/p/CQlptixpNQq/\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHY\nAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n-------- dimesions\n------------ height\n-------------- 1080\n------------ width\n-------------- 1080\n-------- thumbnail_src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------- thumbnails\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n-------------- config_width\n---------------- 150\n-------------- config_height\n---------------- 150\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n-------------- config_width\n---------------- 240\n-------------- config_height\n---------------- 240\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n-------------- config_width\n---------------- 320\n-------------- config_height\n---------------- 320\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n-------------- config_width\n---------------- 480\n-------------- config_height\n---------------- 480\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=1\n09&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------------- config_width\n---------------- 640\n-------------- config_height\n---------------- 640\n-------- owner\n------------ id\n---------------- 48335815772\n------------ username\n---------------- antonnechaev990\n-------- is_video\n---------- False\n-------- text\n------------ Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n-------- comments\n---------- 0\n-------- comments_disabled\n---------- False\n-------- likes\n---------- 1\n-------- location\n---------- None\n-------- timestamp\n---------- 1624721049\n-------- full\n------------ __typename\n---------------- GraphImage\n------------ id\n---------------- 2604671409127216170\n------------ shortcode\n---------------- CQlptixpNQq\n------------ dimensions\n---------------- height\n------------------ 1080\n---------------- width\n------------------ 1080\n------------ display_url\n---------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKp\nqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n------------ edge_media_to_tagged_user\n---------------- edges\n------------ fact_check_overall_rating\n-------------- None\n------------ fact_check_information\n-------------- None\n------------ gating_info\n-------------- None\n------------ sharing_friction_info\n---------------- should_have_sharing_friction\n------------------ False\n---------------- bloks_app_url\n------------------ None\n------------ media_overlay_info\n-------------- None\n------------ media_preview\n---------------- ACoq6Nt3b1/yKXJ9P1rC8+T+835mjz5P7zfmarlOX267P8DbDEcNTgCM5OfT2rBFw5GQzY+poFw7DIZvzNHKP2y7M36WsDz5P7zfmaPPk/vN+Zo5Re3XZkdFFIc9uas4yAjdkr93v/tfT/PNTKQRkdKTLelKM9xikaSd16ba/n3f9bW\ns6iiiqMjY+xReh/M0fYovQ/masOARzUaovoPyrK7PU5I/yr7iH7Gnp+ppwsou4/U1bprDIouxckey+5Fb7FF6H8zR9ii9D+Zq0vSloux8kf5V9x//2Q==\n------------ owner\n---------------- id\n-------------------- 48335815772\n---------------- username\n-------------------- antonnechaev990\n------------ is_video\n-------------- False\n------------ has_upcoming_event\n-------------- False\n------------ accessibility_caption\n---------------- Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n------------ edge_media_to_caption\n---------------- edges\n------------ edge_media_to_comment\n---------------- count\n------------------ 0\n------------ comments_disabled\n-------------- False\n------------ taken_at_timestamp\n-------------- 1624721049\n------------ edge_liked_by\n---------------- count\n------------------ 1\n------------ edge_media_preview_like\n---------------- count\n------------------ 1\n------------ location\n-------------- None\n------------ thumbnail_src\n---------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109\n&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n------------ thumbnail_resources\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n------------------ config_width\n-------------------- 150\n------------------ config_height\n-------------------- 150\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n------------------ config_width\n-------------------- 240\n------------------ config_height\n-------------------- 240\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n------------------ config_width\n-------------------- 320\n------------------ config_height\n-------------------- 320\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n------------------ config_width\n-------------------- 480\n------------------ config_height\n-------------------- 480\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_c\nat=109&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n------------------ config_width\n-------------------- 640\n------------------ config_height\n-------------------- 640\n------------ coauthor_producers\n```\n\n### source_to_data.py\n```python\nimport sys\nfrom insta_checker import InstaChecker, super_print\nimport asyncio\nimport aiohttp\n\n\n# You can make it yourself in the way you prefer\nasync def get_source(url, headers=None, proxy=None):\n    session = aiohttp.ClientSession()\n    response_result = {\n        \'success\': False,\n        \'data\': \'\',\n        \'errors\': [],\n    }\n    try:\n        if proxy and headers:\n            response = await session.get(url, proxy=proxy, headers=headers)\n        elif proxy:\n            response = await session.get(url, proxy=proxy)\n        elif headers:\n            response = await session.get(url, headers=headers)\n        else:\n            response = await session.get(url)\n        if response.status == 200:\n            response_result[\'success\'] = True\n            response_result[\'data\'] = await response.text()\n        else:\n            response_result[\'success\'] = False\n            response_result[\'errors\'].append(f\'Response status is {int(response.status)}\')\n        if \'not-logged-in\' in response_result[\'data\']:\n            response_result[\'success\'] = False\n            response_result[\'errors\'].append(\'Not logged in, provide better headers\')\n    except BaseException as ex:\n        response_result[\'success\'] = True\n        response_result[\'errors\'].append(\n            f"Can\'t fetch and parse the page. Error: \'{ex}\'. On line {sys.exc_info()[-1].tb_lineno}")\n    await session.close()\n    return {url: response_result}\n\n\nasync def main():\n    cookie = \'ds_user_id=48743733271;mid=YQgRZwAAAAEPjPkWIONy9q0lPPdu;sessionid=48743733271%3AJRUhxoYZxBh4BX%3A6;ig_nrcb=1;ig_did=A446BA65-9920-462A-BAA8-F85FEAC0AB98;csrftoken=iD5MZwMnXZHgNzm8H5kACrNHKVBIvpDz;rur="CLN\\05448743733271\\0541659454776:01f7e7cbc38f962c9fbe9fe015e28ac99145941e231df3769a1682f8ce14b2a8ca254ddf";\'\n    checker = InstaChecker(\n        cookie=cookie\n    )\n\n    url = \'https://www.instagram.com/antonnechaev990/\'\n    source_response_result = await get_source(url, checker.headers, checker.proxy)\n\n\n    data = checker.source_to_data(source_response_result[url])\n    success = data[\'success\']\n    errors = data[\'errors\']\n    data = data[\'data\']\n    print(f"{success = }")\n    if success:\n        print(f"{data[\'id\'] = }")\n        print(f"{data[\'avatar_url\'] = }")\n        print(f"{data[\'followers\'] = }")\n        print(f"{data[\'follows\'] = }")\n        print(f"{data[\'media_count\'] = }")\n        print(f"{data[\'recent_media\'][0][\'text\'] = }")\n        print(\'\')\n        print(\'Printing all data:\')\n        super_print(data)\n\n\nasyncio.run(main())\n\n```\n\nOutput:\n```python\nsuccess = True\ndata[\'id\'] = \'48335815772\'\ndata[\'avatar_url\'] = \'https://instagram.faly2-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.faly2-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8-qUQ\nD&edm=ABFeTR8BAAAA&ccb=7-4&oh=0b1e57f6904aabbf9073eb19e4208f0b&oe=6115D58F&_nc_sid=93c1bc&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\'\ndata[\'followers\'] = 1\ndata[\'follows\'] = 2\ndata[\'media_count\'] = 1\ndata[\'recent_media\'][0][\'text\'] = "Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'."\n\nPrinting all data:\n-- id\n------ 48335815772\n-- username\n------ antonnechaev990\n-- connected_fb_page\n---- None\n-- media_count\n---- 1\n-- biography\n------\n-- followers\n---- 1\n-- follows\n---- 2\n-- full_name\n------ Testing\n-- avatar_url\n------ https://instagram.faly2-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.faly2-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8-qUQD&edm=ABFeTR8BA\nAAA&ccb=7-4&oh=0b1e57f6904aabbf9073eb19e4208f0b&oe=6115D58F&_nc_sid=93c1bc&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n-- avatar_url_hd\n------ https://instagram.faly2-1.fna.fbcdn.net/v/t51.2885-19/44884218_345707102882519_2446069589734326272_n.jpg?_nc_ht=instagram.faly2-1.fna.fbcdn.net&_nc_ohc=DTLSrWbkEzYAX8-qUQD&edm=ABFeTR8BA\nAAA&ccb=7-4&oh=0b1e57f6904aabbf9073eb19e4208f0b&oe=6115D58F&_nc_sid=93c1bc&ig_cache_key=YW5vbnltb3VzX3Byb2ZpbGVfcGlj.2-ccb7-4\n-- recent_media\n-------- type\n------------ image\n-------- id\n------------ 2604671409127216170\n-------- shortcode\n------------ CQlptixpNQq\n-------- post_url\n------------ https://www.instagram.com/p/CQlptixpNQq/\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHY\nAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n-------- dimesions\n------------ height\n-------------- 1080\n------------ width\n-------------- 1080\n-------- thumbnail_src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------- thumbnails\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n-------------- config_width\n---------------- 150\n-------------- config_height\n---------------- 150\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n-------------- config_width\n---------------- 240\n-------------- config_height\n---------------- 240\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n-------------- config_width\n---------------- 320\n-------------- config_height\n---------------- 320\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n-------------- config_width\n---------------- 480\n-------------- config_height\n---------------- 480\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=1\n09&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------------- config_width\n---------------- 640\n-------------- config_height\n---------------- 640\n-------- is_video\n---------- False\n-------- text\n------------ Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n-------- comments\n---------- 0\n-------- comments_disabled\n---------- False\n-------- likes\n---------- 1\n-------- owner\n------------ id\n---------------- 48335815772\n------------ username\n---------------- antonnechaev990\n-------- location\n---------- None\n-------- timestamp\n---------- 1624721049\n-------- type\n------------ image\n-------- id\n------------ 2604671409127216170\n-------- shortcode\n------------ CQlptixpNQq\n-------- post_url\n------------ https://www.instagram.com/p/CQlptixpNQq/\n-------- src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKpqHHY\nAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n-------- dimesions\n------------ height\n-------------- 1080\n------------ width\n-------------- 1080\n-------- thumbnail_src\n------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc\n_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------- thumbnails\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n-------------- config_width\n---------------- 150\n-------------- config_height\n---------------- 150\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n-------------- config_width\n---------------- 240\n-------------- config_height\n---------------- 240\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n-------------- config_width\n---------------- 320\n-------------- config_height\n---------------- 320\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_\nohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n-------------- config_width\n---------------- 480\n-------------- config_height\n---------------- 480\n-------------- src\n------------------ https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=1\n09&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n-------------- config_width\n---------------- 640\n-------------- config_height\n---------------- 640\n-------- owner\n------------ id\n---------------- 48335815772\n------------ username\n---------------- antonnechaev990\n-------- is_video\n---------- False\n-------- text\n------------ Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n-------- comments\n---------- 0\n-------- comments_disabled\n---------- False\n-------- likes\n---------- 1\n-------- location\n---------- None\n-------- timestamp\n---------- 1624721049\n-------- full\n------------ __typename\n---------------- GraphImage\n------------ id\n---------------- 2604671409127216170\n------------ shortcode\n---------------- CQlptixpNQq\n------------ dimensions\n---------------- height\n------------------ 1080\n---------------- width\n------------------ 1080\n------------ display_url\n---------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&_nc_ohc=AgfUPKp\nqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=b35547079fcd31703df24659845b524e&oe=61169DA8&_nc_sid=7bff83\n------------ edge_media_to_tagged_user\n---------------- edges\n------------ fact_check_overall_rating\n-------------- None\n------------ fact_check_information\n-------------- None\n------------ gating_info\n-------------- None\n------------ sharing_friction_info\n---------------- should_have_sharing_friction\n------------------ False\n---------------- bloks_app_url\n------------------ None\n------------ media_overlay_info\n-------------- None\n------------ media_preview\n---------------- ACoq6Nt3b1/yKXJ9P1rC8+T+835mjz5P7zfmarlOX267P8DbDEcNTgCM5OfT2rBFw5GQzY+poFw7DIZvzNHKP2y7M36WsDz5P7zfmaPPk/vN+Zo5Re3XZkdFFIc9uas4yAjdkr93v/tfT/PNTKQRkdKTLelKM9xikaSd16ba/n3f9bW\ns6iiiqMjY+xReh/M0fYovQ/masOARzUaovoPyrK7PU5I/yr7iH7Gnp+ppwsou4/U1bprDIouxckey+5Fb7FF6H8zR9ii9D+Zq0vSloux8kf5V9x//2Q==\n------------ owner\n---------------- id\n-------------------- 48335815772\n---------------- username\n-------------------- antonnechaev990\n------------ is_video\n-------------- False\n------------ has_upcoming_event\n-------------- False\n------------ accessibility_caption\n---------------- Photo by Testing on June 26, 2021. May be an image of text that says \'x 6 Game Over × WINNER! Restart game GAMES & TOYS TOOLS\'.\n------------ edge_media_to_caption\n---------------- edges\n------------ edge_media_to_comment\n---------------- count\n------------------ 0\n------------ comments_disabled\n-------------- False\n------------ taken_at_timestamp\n-------------- 1624721049\n------------ edge_liked_by\n---------------- count\n------------------ 1\n------------ edge_media_preview_like\n---------------- count\n------------------ 1\n------------ location\n-------------- None\n------------ thumbnail_src\n---------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109\n&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n------------ thumbnail_resources\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s150x150/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d31413bed658502d2998ce97b9f5aba4&oe=6115D1A3&_nc_sid=7bff83\n------------------ config_width\n-------------------- 150\n------------------ config_height\n-------------------- 150\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s240x240/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=227104b3c78166d9ed08714b8f5b87b0&oe=611708D0&_nc_sid=7bff83\n------------------ config_width\n-------------------- 240\n------------------ config_height\n-------------------- 240\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s320x320/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=d6ce7cdd41f4fa3d6213f68cf3cead27&oe=61160E9D&_nc_sid=7bff83\n------------------ config_width\n-------------------- 320\n------------------ config_height\n-------------------- 320\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/e35/s480x480/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_cat=109&\n_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=17910b3dbb1ac6c6264faee25598d05e&oe=6115DBC1&_nc_sid=7bff83\n------------------ config_width\n-------------------- 480\n------------------ config_height\n-------------------- 480\n------------------ src\n---------------------- https://scontent-hel3-1.cdninstagram.com/v/t51.2885-15/sh0.08/e35/s640x640/207554847_321832179605661_6198453185168062_n.jpg?_nc_ht=scontent-hel3-1.cdninstagram.com&_nc_c\nat=109&_nc_ohc=AgfUPKpqHHYAX_FMAHM&edm=ABfd0MgBAAAA&ccb=7-4&oh=31ce3cd914417eb9b94e203e8580b62f&oe=61165B6A&_nc_sid=7bff83\n------------------ config_width\n-------------------- 640\n------------------ config_height\n-------------------- 640\n------------ coauthor_producers\n```\n',
    'author': 'Anton Nechaev',
    'author_email': 'antonnechaev990@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/gh0st-work/insta_checker',
    'package_dir': package_dir,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
